@@ -234,10 +234,12 @@ public class TagSelectionWidget : TreeView {
 	{
 		// FIXME this should be themable but Gtk# doesn't give me access to the proper
 		// members in GtkStyle for that.
+		/*
 		if (tag is Category)
 			renderer.CellBackground = ToHashColor (this.Style.MidColors [(int) Gtk.StateType.Normal]);
 		else
 			renderer.CellBackground = ToHashColor (this.Style.LightColors [(int) Gtk.StateType.Normal]);
+		*/
 	}
 
 	private void CheckBoxDataFunc (TreeViewColumn column,
@@ -561,7 +563,8 @@ public class TagSelectionWidget : TreeView {
 			return;
 
 		// Check that the tag doesn't already exist
-		if (MainWindow.Toplevel.Database.Tags.GetTagByName (args.NewText) != null) {
+		if (String.Compare (args.NewText, tag.Name, true) != 0 &&
+		    tag_store.GetTagByName (args.NewText) != null) {
 			HigMessageDialog md = new HigMessageDialog (MainWindow.Toplevel.Window,
 				DialogFlags.DestroyWithParent, 
 				MessageType.Warning, ButtonsType.Ok, 
@@ -575,7 +578,7 @@ public class TagSelectionWidget : TreeView {
 		}
 
 		tag.Name = args.NewText;
-		MainWindow.Toplevel.Database.Tags.Commit (tag);
+		tag_store.Commit (tag);
 
 		args.RetVal = true;
 		return;
